@@ -1,11 +1,12 @@
 import os
+from datetime import date
 
 import click
 import pyperclip
 import questionary
 from jinja2 import Environment, PackageLoader
 from semver import VersionInfo
-
+from .util import get_first_git_remote
 from .changelog import Changelog
 
 
@@ -95,7 +96,7 @@ def init(filename):
     # Ask the user for their GitHub repository URL
     github_repo_url: str = questionary.text(
         message='Enter Repository URL',
-        default='https://github.com/atwalsh/kac',
+        default=get_first_git_remote() or 'https://github.com/atwalsh/kac',
     ).ask()
     if github_repo_url is None:
         raise click.Abort
@@ -104,7 +105,8 @@ def init(filename):
     env = Environment(loader=PackageLoader('kac', 'templates'), )
     changelog_template = env.get_template('CHANGELOG.md')
     # Render the template with user input
-    new_file_text = changelog_template.render(initial_release=version, repo_url=github_repo_url)
+    new_file_text = changelog_template.render(initial_release=version, repo_url=github_repo_url,
+                                              initial_release_date=date.today())
 
     # Write the new CHANGELOG file
     try:
